/***************************************************************
 *                 Simula+ configuration file                  *
 *                    simula.plus@cemes.fr                     *
 *	             GNU/linux version 3.0.0	               *
 *            software under General Public License            *
 ***************************************************************
 * copyright © 2006,2012 COLLARD Christophe
 * copyright © 2006,2012 Centre National de la Recherche Scientifique
 * copyright © 2006 Arts et Métiers ParisTech
 * copyright © 2006 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
 * copyright © 2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
 * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
 ***************************************************************/

#ifndef __parameters_h
#define __parameters_h

using namespace std;
#define DEBUG // debug mode
//#define NDEBUG // exploitation mode

//double epsilon = 1e-9;
//double precision = 1e-12;
long double epsilon=1.e-12;     // precision machine pour approximer le zero
long double precision=1.e-15;   // precision machine pour les calculs

#endif


// pb de l'approx
//  double value=1234567890123456789;
//  value += 1.123456789;
//  value -= 1234567890123456789;
//  cout << setprecision(22) << value;
//
// result : value = 0 soit une erreur en 1.e-1 !! (et ca peut etre pire!)
